; StyleS/theme.jl

;; Copyright (C) 1999 Sander Klein Lebbink <sander@cerberus.demon.nl>

;; theme ported from the enlightenment-theme 'stylE'
;; by Andrew Cattau <cattand@charlie.cns.iit.edu>

(defgroup StyleP-frame "StyleP")

(defcustom StyleP:text-color "gray"
  "Title foreground color - not active"
  :group StyleP-frame
  :type color
  :after-set after-setting-frame-option)

(defcustom StyleP:text-color-a "white"
  "Title foreground color - active"
  :group StyleP-frame
  :type color
  :after-set after-setting-frame-option)

(defcustom StyleP:normal-title-just 'left
  "Title justification in normal border state"
  :group StyleP-frame
  :type symbol
  :options (left center right)
  :after-set after-setting-frame-option)

(defcustom StyleP:transient-title-just 'left
  "Title justification in transient border state"
  :group StyleP-frame
  :type symbol
  :options (left center right)
  :after-set after-setting-frame-option)

(defcustom StyleP:normal-title-fromside 2
  "Title distance from side in normal border state"
  :group StyleP-frame
  :type number
  :range (0 . 250)
  :after-set after-setting-frame-option)

(defcustom StyleP:transient-title-fromside 2
  "Title destance from side in transient border state"
  :group StyleP-frame
  :type number
  :range (0 . 250)
  :after-set after-setting-frame-option)

(defcustom StyleP:normal-shade-with-borders 't
  "Display border around titlebar when shading normal windows"
  :group StyleP-frame
  :type boolean
  :after-set after-setting-frame-option)

(defcustom StyleP:transient-shade-with-borders 't
  "Display border around titlebar when shading transient windows"
  :group StyleP-frame
  :type boolean
  :after-set after-setting-frame-option)

(let*

  (

    (normal-just
      (if (eq StyleP:normal-title-just 'left)
	StyleP:normal-title-fromside
	StyleP:normal-title-just
      )
    )

    (transient-just
      (if (eq StyleP:transient-title-just 'left)
	StyleP:transient-title-fromside
	StyleP:transient-title-just
      )
    )

    (normal-right-width
      (lambda ()
	StyleP:normal-title-fromside
      )
    )

    (normal-fromside
      (lambda ()
	(+ 40 StyleP:normal-title-fromside)
      )
    )

    (transient-right-width
      (lambda ()
	StyleP:transient-title-fromside
      )
    )

    (transient-fromside
      (lambda ()
	(+ 16 StyleP:transient-title-fromside)
      )
    )

    (bottom-images
      (make-image "b.png")
    )

    (top-left-images
      (make-image "tl.png")
    )

    (top-images
      (list
        (make-image "bar.png")
        (make-image "bar_a.png")
      )
    )

    (bar-left
      (list
	(make-image "bar_left.png")
	(make-image "bar_left_a.png")
      )
    )

    (bar-right
      (list
        (make-image "bar_right.png")
	(make-image "bar_right_a.png")
      )
    )

    (top-right-images
      (make-image "tr.png")
    )

    (bottom-left-images
      (make-image "bl.png")
    )

    (bottom-right-images
      (make-image "br.png")
    )

    (close-images
      (list
        (make-image "btn_kill_0.png")
        (make-image "btn_kill_1.png")
        (make-image "btn_kill_2.png")
	(make-image "btn_kill_3.png")
      )
    )

    (maximize-images
      (list
        (make-image "btn_max_0.png")
        (make-image "btn_max_1.png")
        (make-image "btn_max_2.png")
	(make-image "btn_max_3.png")
      )
    )

    (iconify-images
      (list
        (make-image "btn_iconify_0.png")
        (make-image "btn_iconify_1.png")
        (make-image "btn_iconify_2.png")
	(make-image "btn_iconify_3.png")
      )
    )

    (menu-images
      (list
        (make-image "btn_menu_0.png")
        (make-image "btn_menu_1.png")
        (make-image "btn_menu_2.png")
	(make-image "btn_menu_3.png")
      )
    )

    (left-images
      (make-image "l.png")
    )

    (right-images
      (make-image "r.png")
    )

    (top-line
      (flip-image-diagonally
        (copy-image left-images)
      )
    )

    (trans-images
      (make-image "trans.png")
    )

    (font-style
      (condition-case nil
        (get-font "-b&h-lucida-medium-r-normal-*-*-100-*-*-p-*-*-*")
      (error
        (condition-case nil
          (get-font "-adobe-helvetica-medium-r-normal-*-*-100-*-*-p-*-*-*")
        (error default-font)
       )
      )
     )
    )

    ;; frame layout

    (frame
     `(
	;; top-left corner
        (
         (background . ,top-left-images)
	 (left-edge . -4)
	 (top-edge . -12)
	 (class . top-left-corner)
        )

        ;; menu bar
        (
         (background . ,menu-images)
	 (top-edge . -8)
	 (left-edge . 0)
	 (class . menu-button)
        )

	;; top bar left-side
	(
	 (background . ,bar-left)
	 (top-edge . -12)
	 (left-edge . 24)
	 (class . title)
	)

        ;; top bar
        (
         (background . ,top-images)
	 (foreground . (,StyleP:text-color ,StyleP:text-color-a))
	 (text . ,window-name)
	 (font . ,font-style)
         (x-justify . ,normal-just)
	 (y-justify . center)
	 (top-edge . -12)
	 (left-edge . 28)
	 (right-edge . ,normal-fromside)
	 (class . title)
        )

	;; extra piece of bar
	(
	 (background . ,top-images)
	 (top-edge . -12)
	 (right-edge . 40)
	 (width . ,normal-right-width)
	 (class . title)
	)

	;; close button
	(
	 (background . ,close-images)
	 (right-edge . 28)
	 (top-edge . -12)
	 (class . close-button)
	)

	;; top bar right-side
	(
	 (background . ,bar-right)
	 (right-edge . 24)
	 (top-edge . -12)
	 (class . title)
	)

	;; maximize button
	(
	 (background . ,maximize-images)
	 (right-edge . 0)
	 (top-edge . -8)
	 (class . maximize-button)
	)

	;; iconify button
	(
	 (background . ,iconify-images)
	 (right-edge . 12)
	 (top-edge . -8)
	 (class . iconify-button)
	)

	;; extra bar left
	(
	 (background . ,top-line)
	 (left-edge . 4)
	 (top-edge . -12)
	 (width . 20)
	 (class . title)
	)

	;; extra bar right
	(
	 (background . ,top-line)
	 (right-edge . 4)
	 (top-edge . -12)
	 (width . 20)
	 (class . title)
	)

        ;; top-right corner
        (
         (background . ,top-right-images)
	 (right-edge . -4)
	 (top-edge . -12)
	 (class . top-right-corner)
        )

        ;; left border
        (
         (background . ,left-images)
	 (left-edge . -4)
	 (top-edge . -4)
	 (bottom-edge . 4)
	 (class . left-border)
        )

        ;; right border
        (
         (background . ,right-images)
	 (right-edge . -4)
	 (top-edge . -4)
	 (bottom-edge . 4)
	 (class . right-border)
        )

        ;; bottom border
        (
         (background . ,bottom-images)
	 (left-edge . 4)
	 (right-edge . 4)
	 (bottom-edge . -4)
	 (class . bottom-border)
        )

        ;; bottom-left corner
        (
         (background . ,bottom-left-images)
	 (left-edge . -4)
	 (bottom-edge . -4)
	 (class . bottom-left-corner)
	)

	;; bottom-right corner
	(
	 (background . ,bottom-right-images)
	 (right-edge . -4)
	 (bottom-edge . -4)
	 (class . bottom-right-corner)
	)

      )
    )

    (shaped-frame
     `(
	;; left-transparency
	(
	 (background . ,trans-images)
	 (top-edge . -4)
	 (left-edge . -4)
	 (class . left-border)
	)

        ;; menu bar
        (
         (background . ,menu-images)
	 (top-edge . -8)
	 (left-edge . 0)
	 (class . menu-button)
        )

	;; top bar left-side
	(
	 (background . ,bar-left)
	 (top-edge . -12)
	 (left-edge . 24)
	 (class . title)
	)

        ;; top bar
        (
         (background . ,top-images)
	 (foreground . (,StyleP:text-color ,StyleP:text-color-a))
	 (text . ,window-name)
	 (font . ,font-style)
         (x-justify . ,normal-just)
	 (y-justify . center)
	 (top-edge . -12)
	 (left-edge . 28)
	 (right-edge . ,normal-fromside)
	 (class . title)
        )

	;; extra piece bar
	(
	 (background . ,top-images)
	 (top-edge . -12)
	 (right-edge . 40)
	 (width . ,normal-right-width)
	 (class . title)
	)

	;; close button
	(
	 (background . ,close-images)
	 (right-edge . 28)
	 (top-edge . -12)
	 (class . close-button)
	)

	;; top bar right-side
	(
	 (background . ,bar-right)
	 (right-edge . 24)
	 (top-edge . -12)
	 (class . title)
	)

	;; maximize button
	(
	 (background . ,maximize-images)
	 (right-edge . 0)
	 (top-edge . -8)
	 (class . maximize-button)
	)

	;; iconify button
	(
	 (background . ,iconify-images)
	 (right-edge . 12)
	 (top-edge . -8)
	 (class . iconify-button)
	)

	;; right transparency
	(
	 (background . ,trans-images)
	 (right-edge . -4)
	 (top-edge . -4)
	 (class . right-border)
	)

      )
    )

    (normal-shade-frame
    `(
        ;; menu bar
        (
         (background . ,menu-images)
	 (top-edge . -8)
	 (left-edge . 0)
	 (class . menu-button)
        )

	;; top bar left-side
	(
	 (background . ,bar-left)
	 (top-edge . -12)
	 (left-edge . 24)
	 (class . title)
	)

        ;; top bar
        (
         (background . ,top-images)
	 (foreground . (,StyleP:text-color ,StyleP:text-color-a))
	 (text . ,window-name)
	 (font . ,font-style)
         (x-justify . ,normal-just)
	 (y-justify . center)
	 (top-edge . -12)
	 (left-edge . 28)
	 (right-edge . ,normal-fromside)
	 (class . title)
        )

	;; extra piece of bar
	(
	 (background . ,top-images)
	 (top-edge . -12)
	 (right-edge . 40)
	 (width . ,normal-right-width)
	 (class . title)
	)

	;; close button
	(
	 (background . ,close-images)
	 (right-edge . 28)
	 (top-edge . -12)
	 (class . close-button)
	)

	;; top bar right-side
	(
	 (background . ,bar-right)
	 (right-edge . 24)
	 (top-edge . -12)
	 (class . title)
	)

	;; maximize button
	(
	 (background . ,maximize-images)
	 (right-edge . 0)
	 (top-edge . -8)
	 (class . maximize-button)
	)

	;; iconify button
	(
	 (background . ,iconify-images)
	 (right-edge . 12)
	 (top-edge . -8)
	 (class . iconify-button)
	)

	;; top-left corner
	(
	 (background . ,top-left-images)
	 (left-edge . -4)
	 (top-edge . -12)
	 (class . title)
	)

	;; top border left
	(
	 (background . ,top-line)
	 (left-edge . 4)
	 (top-edge . -12)
	 (width . 20)
	 (class . title)
	)

	;; top border right
	(
	 (background . ,top-line)
	 (right-edge . 4)
	 (top-edge . -12)
	 (width . 20)
	 (class . title)
	)

	;; top-right corner
	(
	 (background . ,top-right-images)
	 (right-edge . -4)
	 (top-edge . -12)
	 (class . title)
	)

	;; right border
	(
	 (background . ,right-images)
	 (right-edge . -4)
	 (top-edge . -8)
	 (height . 2)
	 (class . title)
	)

	;; bottom-right corner
	(
	 (background . ,bottom-right-images)
	 (right-edge . -4)
	 (top-edge . -4) 
	 (class . title)
	)

	;; bottom border
	(
	 (background . ,bottom-images)
	 (right-edge . 4)
	 (top-edge . 0)
	 (left-edge . 4)
	 (class . title)
	)

	;; bottom-left corner
	(
	 (background . ,bottom-left-images)
	 (left-edge . -4)
	 (top-edge . -4)
	 (class . title)
	)

	;; left border
	(
	 (background . ,left-images)
	 (left-edge . -4)
	 (top-edge . -8)
	 (height . 2)
	 (class . title)
	)

      )
    )

    (small-border-frame
     `(
	;; top bar left
	(
	 (background . ,bar-left)
	 (left-edge . 0)
	 (top-edge . -12)
	 (class . title)
	)

	;; title-bar
	(
	 (background . ,top-images)
	 (foreground . (,StyleP:text-color ,StyleP:text-color-a))
	 (text . ,window-name)
	 (font . ,font-style)
         (x-justify . ,transient-just)
	 (y-justify . center)
	 (left-edge . 4)
	 (top-edge . -12)
	 (right-edge . ,transient-fromside)
	 (class . title)
	)

	;; extra piece of bar
	(
	 (background . ,top-images)
	 (top-edge . -12)
	 (right-edge . 16)
	 (width . ,transient-right-width)
	 (class . title)
	)

	;; close button
	(
	 (background . ,close-images)
	 (right-edge . 4)
	 (top-edge . -12)
	 (class . close-button)
	)

	;; top bar right
	(
	 (background . ,bar-right)
	 (right-edge . 0)
	 (top-edge . -12)
	 (class . title)
	)

	;; top-left corner
	(
	 (background . ,top-left-images)
	 (left-edge . -4)
	 (top-edge . -16)
	 (class . top-left-corner)
	)

	;; top-right corner
	(
	 (background . ,top-right-images)
	 (right-edge . -4)
	 (top-edge . -16)
	 (class . top-right-corner)
	)

	;; top border
	(
	 (background . ,top-line)
	 (left-edge . 4)
	 (right-edge . 4)
	 (top-edge . -16)
	 (class . top-border)
	)

	;; bottom border
	(
	 (background . ,bottom-images)
	 (left-edge . 4)
	 (right-edge . 4)
	 (bottom-edge . -4)
	 (class . bottom-border)
	)

	;; bottom-left corner
	(
	 (background . ,bottom-left-images)
	 (left-edge . -4)
	 (bottom-edge . -4)
	 (class . bottom-left-corner)
	)

	;; bottom-right corner
	(
	 (background . ,bottom-right-images)
	 (right-edge . -4)
	 (bottom-edge . -4)
	 (class . bottom-right-corner)
	)

	;; right border
	(
	 (background . ,right-images)
	 (right-edge . -4)
	 (top-edge . -8)
	 (bottom-edge . 4)
	 (class . right-border)
	)

	;; left border
	(
	 (background . ,left-images)
	 (left-edge . -4)
	 (top-edge . -8)
	 (bottom-edge . 4)
	 (class . left-border)
	)

      )
    )

    (title-only-frame
     `(
	;; transparency left
	(
	 (background . ,trans-images)
	 (left-edge . -4)
	 (top-edge . -16)
	 (class . title)
	)

	;; left-side bar
	(
	 (background . ,bar-left)
	 (left-edge . 0)
	 (top-edge . -12)
	 (class . title)
	)

	;; title bar
	(
	 (background . ,top-images)
	 (foreground . (,StyleP:text-color ,StyleP:text-color-a))
	 (text . ,window-name)
	 (font . ,font-style)
	 (x-justify . ,transient-just)
	 (y-justify . center)
	 (left-edge . 4)
	 (right-edge . ,transient-fromside)
	 (top-edge . -12)
	 (class . title)
	)

	;; extra piece of bar
	(
	 (background . ,top-images)
	 (top-edge . -12)
	 (right-edge . 16)
	 (width . ,transient-right-width)
	 (class . title)
	)

	;; close button
	(
	 (background . ,close-images)
	 (right-edge . 4)
	 (top-edge . -12)
	 (class . close-button)
	)

	;; right-side bar
	(
	 (background . ,bar-right)
	 (right-edge . 0)
	 (top-edge . -12)
	 (class . title)
	)

	;; right transparency
	(
	 (background . ,trans-images)
	 (right-edge . -4)
	 (top-edge . -16)
	 (class . title)
	)

      )
    )

    (title-only-bar-frame
     `(
	;; left-side bar
	(
	 (background . ,bar-left)
	 (left-edge . 0)
	 (top-edge . -12)
	 (class . title)
	)

	;; title bar
	(
	 (background . ,top-images)
	 (foreground . (,StyleP:text-color ,StyleP:text-color-a))
	 (text . ,window-name)
	 (font . ,font-style)
	 (x-justify . ,transient-just)
	 (y-justify . center)
	 (left-edge . 4)
	 (right-edge . ,transient-fromside)
	 (top-edge . -12)
	 (class . title)
	)

	;; extra piece of bar
	(
	 (background . ,top-images)
	 (top-edge . -12)
	 (right-edge . 16)
	 (width . ,transient-right-width)
	 (class . title)
	)

	;; close button
	(
	 (background . ,close-images)
	 (right-edge . 4)
	 (top-edge . -12)
	 (class . close-button)
	)

	;; right-side bar
	(
	 (background . ,bar-right)
	 (right-edge . 0)
	 (top-edge . -12)
	 (class . title)
	)

	;; top-left corner
	(
	 (background . ,top-left-images)
	 (left-edge . -4)
	 (top-edge . -16)
	 (class . title)
	)

	;; top border
	(
	 (background . ,top-line)
	 (left-edge . 4)
	 (top-edge . -16)
	 (right-edge . 4)
	 (class . title)
	)

	;; top-right corner
	(
	 (background . ,top-right-images)
	 (right-edge . -4)
	 (top-edge . -16)
	 (class . title)
	)

	;; right border
	(
	 (background . ,right-images)
	 (right-edge . -4)
	 (top-edge . -8)
	 (height . 4)
	 (class . title)
	)

	;; bottom-right corner
	(
	 (background . ,bottom-right-images)
	 (right-edge . -4)
	 (top-edge . -4)
	 (class . title)
	)

	;; bottom border
	(
	 (background . ,bottom-images)
	 (right-edge . 4)
	 (left-edge . 4)
	 (top-edge . 0)
	 (class . title)
	)

	;; bottom-left corner
	(
	 (background . ,bottom-left-images)
	 (left-edge . -4)
	 (top-edge . -4)
	 (class . title)
	)

	;; left border
	(
	 (background . ,left-images)
	 (left-edge . -4)
	 (top-edge . -8)
	 (height . 4)
	 (class . title)
	)
      )
    )

)

(add-frame-style 'StyleP
  (lambda (w type)
    (cond 
      (
       (eq type 'shaped)
        (if (window-get w 'shaded)
          (if (eq StyleP:normal-shade-with-borders 't)
	    (if (eq (window-get w 'shaded-old-type) 'shaped)
	      shaped-frame
	      normal-shade-frame
	    )
	    shaped-frame
	  )
	  shaped-frame
	)
      )
      (
       (eq type 'transient)
        small-border-frame
      )
      (
       (eq type 'shaped-transient)
	(if (window-get w 'shaded)
	  (if (eq StyleP:transient-shade-with-borders 't)
	    (if (eq (window-get w 'shaded-old-type) 'shaped-transient)
	      title-only-frame
	      title-only-bar-frame
	    )
	    title-only-frame
	  )
	  title-only-frame
	)
      )
      (
       (eq type 'unframed)
	nil-frame
      )
       (t frame)
      )
    )
  )
)
